# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import TYPE_CHECKING, Dict, List, Union, Optional
from datetime import datetime
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "Task",
    "Main",
    "MainEvaluateStep",
    "MainToolCallStep",
    "MainPromptStepOutput",
    "MainPromptStepOutputPromptUnionMember0",
    "MainPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainPromptStepOutputPromptUnionMember0ToolCall",
    "MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainPromptStepOutputToolChoice",
    "MainPromptStepOutputToolChoiceNamedToolChoice",
    "MainPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainPromptStepOutputToolsUnionMember1",
    "MainPromptStepOutputToolsUnionMember1ToolRef",
    "MainPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainGetStep",
    "MainSetStep",
    "MainLogStep",
    "MainYieldStep",
    "MainReturnStep",
    "MainSleepStep",
    "MainSleepStepSleep",
    "MainErrorWorkflowStep",
    "MainWaitForInputStep",
    "MainWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepOutput",
    "MainIfElseWorkflowStepOutputThen",
    "MainIfElseWorkflowStepOutputThenWaitForInputStep",
    "MainIfElseWorkflowStepOutputThenWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepOutputThenEvaluateStep",
    "MainIfElseWorkflowStepOutputThenToolCallStep",
    "MainIfElseWorkflowStepOutputThenPromptStepOutput",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolChoice",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenGetStep",
    "MainIfElseWorkflowStepOutputThenSetStep",
    "MainIfElseWorkflowStepOutputThenLogStep",
    "MainIfElseWorkflowStepOutputThenYieldStep",
    "MainIfElseWorkflowStepOutputThenReturnStep",
    "MainIfElseWorkflowStepOutputThenSleepStep",
    "MainIfElseWorkflowStepOutputThenSleepStepSleep",
    "MainIfElseWorkflowStepOutputThenErrorWorkflowStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutput",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitch",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThen",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenEvaluateStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenToolCallStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutput",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolChoice",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenGetStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenSetStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenLogStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenYieldStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenReturnStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenSleepStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenSleepStepSleep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenErrorWorkflowStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenWaitForInputStep",
    "MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepOutputThenForeachStepOutput",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeach",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDo",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoWaitForInputStep",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoEvaluateStep",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoToolCallStep",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutput",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolChoice",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoGetStep",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoSetStep",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoLogStep",
    "MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoYieldStep",
    "MainIfElseWorkflowStepOutputThenParallelStepOutput",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallel",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelEvaluateStep",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelToolCallStep",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutput",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolChoice",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelGetStep",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelSetStep",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelLogStep",
    "MainIfElseWorkflowStepOutputThenParallelStepOutputParallelYieldStep",
    "MainIfElseWorkflowStepOutputThenThenOutput",
    "MainIfElseWorkflowStepOutputThenThenOutputMap",
    "MainIfElseWorkflowStepOutputThenThenOutputMapEvaluateStep",
    "MainIfElseWorkflowStepOutputThenThenOutputMapToolCallStep",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutput",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolChoice",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainIfElseWorkflowStepOutputThenThenOutputMapGetStep",
    "MainIfElseWorkflowStepOutputThenThenOutputMapSetStep",
    "MainIfElseWorkflowStepOutputThenThenOutputMapLogStep",
    "MainIfElseWorkflowStepOutputThenThenOutputMapYieldStep",
    "MainIfElseWorkflowStepOutputElse",
    "MainIfElseWorkflowStepOutputElseWaitForInputStep",
    "MainIfElseWorkflowStepOutputElseWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepOutputElseEvaluateStep",
    "MainIfElseWorkflowStepOutputElseToolCallStep",
    "MainIfElseWorkflowStepOutputElsePromptStepOutput",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolChoice",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseGetStep",
    "MainIfElseWorkflowStepOutputElseSetStep",
    "MainIfElseWorkflowStepOutputElseLogStep",
    "MainIfElseWorkflowStepOutputElseYieldStep",
    "MainIfElseWorkflowStepOutputElseReturnStep",
    "MainIfElseWorkflowStepOutputElseSleepStep",
    "MainIfElseWorkflowStepOutputElseSleepStepSleep",
    "MainIfElseWorkflowStepOutputElseErrorWorkflowStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutput",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitch",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThen",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenEvaluateStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenToolCallStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutput",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolChoice",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenGetStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenSetStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenLogStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenYieldStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenReturnStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenSleepStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenSleepStepSleep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenErrorWorkflowStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenWaitForInputStep",
    "MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepOutputElseForeachStepOutput",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeach",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDo",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoWaitForInputStep",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoWaitForInputStepWaitForInput",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoEvaluateStep",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoToolCallStep",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutput",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolChoice",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoGetStep",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoSetStep",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoLogStep",
    "MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoYieldStep",
    "MainIfElseWorkflowStepOutputElseParallelStepOutput",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallel",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelEvaluateStep",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelToolCallStep",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutput",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolChoice",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelGetStep",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelSetStep",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelLogStep",
    "MainIfElseWorkflowStepOutputElseParallelStepOutputParallelYieldStep",
    "MainIfElseWorkflowStepOutputElseElseOutput",
    "MainIfElseWorkflowStepOutputElseElseOutputMap",
    "MainIfElseWorkflowStepOutputElseElseOutputMapEvaluateStep",
    "MainIfElseWorkflowStepOutputElseElseOutputMapToolCallStep",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutput",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCall",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolChoice",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolChoiceNamedToolChoice",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainIfElseWorkflowStepOutputElseElseOutputMapGetStep",
    "MainIfElseWorkflowStepOutputElseElseOutputMapSetStep",
    "MainIfElseWorkflowStepOutputElseElseOutputMapLogStep",
    "MainIfElseWorkflowStepOutputElseElseOutputMapYieldStep",
    "MainSwitchStepOutput",
    "MainSwitchStepOutputSwitch",
    "MainSwitchStepOutputSwitchThen",
    "MainSwitchStepOutputSwitchThenEvaluateStep",
    "MainSwitchStepOutputSwitchThenToolCallStep",
    "MainSwitchStepOutputSwitchThenPromptStepOutput",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCall",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolChoice",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoice",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainSwitchStepOutputSwitchThenGetStep",
    "MainSwitchStepOutputSwitchThenSetStep",
    "MainSwitchStepOutputSwitchThenLogStep",
    "MainSwitchStepOutputSwitchThenYieldStep",
    "MainSwitchStepOutputSwitchThenReturnStep",
    "MainSwitchStepOutputSwitchThenSleepStep",
    "MainSwitchStepOutputSwitchThenSleepStepSleep",
    "MainSwitchStepOutputSwitchThenErrorWorkflowStep",
    "MainSwitchStepOutputSwitchThenWaitForInputStep",
    "MainSwitchStepOutputSwitchThenWaitForInputStepWaitForInput",
    "MainForeachStepOutput",
    "MainForeachStepOutputForeach",
    "MainForeachStepOutputForeachDo",
    "MainForeachStepOutputForeachDoWaitForInputStep",
    "MainForeachStepOutputForeachDoWaitForInputStepWaitForInput",
    "MainForeachStepOutputForeachDoEvaluateStep",
    "MainForeachStepOutputForeachDoToolCallStep",
    "MainForeachStepOutputForeachDoPromptStepOutput",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCall",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainForeachStepOutputForeachDoPromptStepOutputToolChoice",
    "MainForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoice",
    "MainForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainForeachStepOutputForeachDoGetStep",
    "MainForeachStepOutputForeachDoSetStep",
    "MainForeachStepOutputForeachDoLogStep",
    "MainForeachStepOutputForeachDoYieldStep",
    "MainParallelStepOutput",
    "MainParallelStepOutputParallel",
    "MainParallelStepOutputParallelEvaluateStep",
    "MainParallelStepOutputParallelToolCallStep",
    "MainParallelStepOutputParallelPromptStepOutput",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCall",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainParallelStepOutputParallelPromptStepOutputToolChoice",
    "MainParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoice",
    "MainParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainParallelStepOutputParallelGetStep",
    "MainParallelStepOutputParallelSetStep",
    "MainParallelStepOutputParallelLogStep",
    "MainParallelStepOutputParallelYieldStep",
    "MainMainOutput",
    "MainMainOutputMap",
    "MainMainOutputMapEvaluateStep",
    "MainMainOutputMapToolCallStep",
    "MainMainOutputMapPromptStepOutput",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1Content",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCall",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022",
    "MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022",
    "MainMainOutputMapPromptStepOutputToolChoice",
    "MainMainOutputMapPromptStepOutputToolChoiceNamedToolChoice",
    "MainMainOutputMapPromptStepOutputToolChoiceNamedToolChoiceFunction",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRefRef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutput",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem",
    "MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022",
    "MainMainOutputMapGetStep",
    "MainMainOutputMapSetStep",
    "MainMainOutputMapLogStep",
    "MainMainOutputMapYieldStep",
    "Tool",
    "ToolAPICall",
    "ToolBash20241022",
    "ToolComputer20241022",
    "ToolFunction",
    "ToolIntegration",
    "ToolIntegrationDummyIntegrationDef",
    "ToolIntegrationBraveIntegrationDef",
    "ToolIntegrationBraveIntegrationDefArguments",
    "ToolIntegrationBraveIntegrationDefSetup",
    "ToolIntegrationEmailIntegrationDef",
    "ToolIntegrationEmailIntegrationDefArguments",
    "ToolIntegrationEmailIntegrationDefSetup",
    "ToolIntegrationSpiderIntegrationDefOutput",
    "ToolIntegrationSpiderIntegrationDefOutputArguments",
    "ToolIntegrationSpiderIntegrationDefOutputSetup",
    "ToolIntegrationWikipediaIntegrationDef",
    "ToolIntegrationWikipediaIntegrationDefArguments",
    "ToolIntegrationWeatherIntegrationDef",
    "ToolIntegrationWeatherIntegrationDefArguments",
    "ToolIntegrationWeatherIntegrationDefSetup",
    "ToolIntegrationBrowserbaseContextIntegrationDef",
    "ToolIntegrationBrowserbaseContextIntegrationDefArguments",
    "ToolIntegrationBrowserbaseContextIntegrationDefSetup",
    "ToolIntegrationBrowserbaseExtensionIntegrationDef",
    "ToolIntegrationBrowserbaseExtensionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseExtensionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDef",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments",
    "ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDef",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDef",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDef",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments",
    "ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments",
    "ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup",
    "ToolIntegrationRemoteBrowserIntegrationDef",
    "ToolIntegrationRemoteBrowserIntegrationDefSetup",
    "ToolIntegrationRemoteBrowserIntegrationDefArguments",
    "ToolIntegrationLlamaParseIntegrationDef",
    "ToolIntegrationLlamaParseIntegrationDefArguments",
    "ToolIntegrationLlamaParseIntegrationDefSetup",
    "ToolIntegrationFfmpegIntegrationDef",
    "ToolIntegrationFfmpegIntegrationDefArguments",
    "ToolIntegrationCloudinaryUploadIntegrationDef",
    "ToolIntegrationCloudinaryUploadIntegrationDefArguments",
    "ToolIntegrationCloudinaryUploadIntegrationDefSetup",
    "ToolIntegrationCloudinaryEditIntegrationDef",
    "ToolIntegrationCloudinaryEditIntegrationDefArguments",
    "ToolIntegrationCloudinaryEditIntegrationDefSetup",
    "ToolIntegrationArxivIntegrationDef",
    "ToolIntegrationArxivIntegrationDefArguments",
    "ToolSystem",
    "ToolTextEditor20241022",
]


class MainEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainPromptStepOutputPromptUnionMember0ContentUnionMember1Content(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(BaseModel):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(BaseModel):
    image_url: MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(BaseModel):
    content: Union[
        List[
            MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(BaseModel):
    function: MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022] = None

    computer_20241022: Optional[MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[List[str], List[MainPromptStepOutputPromptUnionMember0ContentUnionMember1], str, None] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[MainPromptStepOutputPromptUnionMember0ToolCall]] = None


class MainPromptStepOutputToolChoiceNamedToolChoiceFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[MainPromptStepOutputToolChoiceNamedToolChoiceFunction] = None


MainPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainPromptStepOutputToolChoiceNamedToolChoice, None
]


class MainPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(BaseModel):
    id: Optional[str] = None


class MainPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(BaseModel):
    name: Optional[str] = None


MainPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(BaseModel):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(BaseModel):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(BaseModel):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(BaseModel):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(BaseModel):
    query: str


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(BaseModel):
    api_key: str


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(BaseModel):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup] = (
        None
    )
    """Integration definition for Brave Search"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(BaseModel):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(BaseModel):
    host: str

    password: str

    port: int

    user: str


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(BaseModel):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup] = (
        None
    )
    """Setup parameters for Email integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(BaseModel):
    spider_api_key: str


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(BaseModel):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(BaseModel):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(BaseModel):
    location: str


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(BaseModel):
    openweathermap_api_key: str


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(BaseModel):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(BaseModel):
    setup: MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(BaseModel):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(BaseModel):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(BaseModel):
    cmd: str

    file: Union[str, List[str], None] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(BaseModel):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(BaseModel):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(BaseModel):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(BaseModel):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(BaseModel):
    arguments: Optional[
        MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(BaseModel):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainPromptStepOutputToolsUnionMember1CreateToolRequestOutput(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall] = None
    """API call definition"""

    bash_20241022: Optional[MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022] = None

    computer_20241022: Optional[MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction] = None
    """Function definition"""

    integration: Optional[MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration] = None
    """Brave integration definition"""

    system: Optional[MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem] = None
    """System definition"""

    text_editor_20241022: Optional[MainPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022] = (
        None
    )


MainPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainPromptStepOutputToolsUnionMember1ToolRef, MainPromptStepOutputToolsUnionMember1CreateToolRequestOutput
]


class MainPromptStepOutput(BaseModel):
    prompt: Union[List[MainPromptStepOutputPromptUnionMember0], str]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainPromptStepOutputToolChoice] = None

    tools: Union[Literal["all"], List[MainPromptStepOutputToolsUnionMember1], None] = None

    unwrap: Optional[bool] = None


class MainGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainReturnStep(BaseModel):
    return_: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]] = FieldInfo(alias="return")

    kind: Optional[Literal["return"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSleepStepSleep(BaseModel):
    days: Optional[int] = None

    hours: Optional[int] = None

    minutes: Optional[int] = None

    seconds: Optional[int] = None


class MainSleepStep(BaseModel):
    sleep: MainSleepStepSleep

    kind: Optional[Literal["sleep"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainErrorWorkflowStep(BaseModel):
    error: str

    kind: Optional[Literal["error"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainWaitForInputStepWaitForInput(BaseModel):
    info: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]]


class MainWaitForInputStep(BaseModel):
    wait_for_input: MainWaitForInputStepWaitForInput

    kind: Optional[Literal["wait_for_input"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenWaitForInputStepWaitForInput(BaseModel):
    info: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]]


class MainIfElseWorkflowStepOutputThenWaitForInputStep(BaseModel):
    wait_for_input: MainIfElseWorkflowStepOutputThenWaitForInputStepWaitForInput

    kind: Optional[Literal["wait_for_input"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(BaseModel):
    function: MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str],
        List[MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ContentUnionMember1],
        str,
        None,
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0ToolCall]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolChoiceNamedToolChoiceFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[MainIfElseWorkflowStepOutputThenPromptStepOutputToolChoiceNamedToolChoiceFunction] = None


MainIfElseWorkflowStepOutputThenPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainIfElseWorkflowStepOutputThenPromptStepOutputToolChoiceNamedToolChoice, None
]


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(BaseModel):
    id: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(BaseModel):
    name: Optional[str] = None


MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(BaseModel):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(
    BaseModel
):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(BaseModel):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(BaseModel):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem] = (
        None
    )
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainIfElseWorkflowStepOutputThenPromptStepOutput(BaseModel):
    prompt: Union[List[MainIfElseWorkflowStepOutputThenPromptStepOutputPromptUnionMember0], str]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainIfElseWorkflowStepOutputThenPromptStepOutputToolChoice] = None

    tools: Union[Literal["all"], List[MainIfElseWorkflowStepOutputThenPromptStepOutputToolsUnionMember1], None] = None

    unwrap: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenReturnStep(BaseModel):
    return_: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]] = FieldInfo(alias="return")

    kind: Optional[Literal["return"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSleepStepSleep(BaseModel):
    days: Optional[int] = None

    hours: Optional[int] = None

    minutes: Optional[int] = None

    seconds: Optional[int] = None


class MainIfElseWorkflowStepOutputThenSleepStep(BaseModel):
    sleep: MainIfElseWorkflowStepOutputThenSleepStepSleep

    kind: Optional[Literal["sleep"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenErrorWorkflowStep(BaseModel):
    error: str

    kind: Optional[Literal["error"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(
    BaseModel
):
    function: MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str],
        List[
            MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1
        ],
        str,
        None,
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[
        List[MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCall]
    ] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoiceFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoiceFunction
    ] = None


MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoice,
    None,
]


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(
    BaseModel
):
    id: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(
    BaseModel
):
    name: Optional[str] = None


MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(
    BaseModel
):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(
    BaseModel
):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(
    BaseModel
):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(
    BaseModel
):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput(
    BaseModel
):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem
    ] = None
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutput(BaseModel):
    prompt: Union[
        List[MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0], str
    ]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolChoice] = None

    tools: Union[
        Literal["all"],
        List[MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1],
        None,
    ] = None

    unwrap: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenReturnStep(BaseModel):
    return_: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]] = FieldInfo(alias="return")

    kind: Optional[Literal["return"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenSleepStepSleep(BaseModel):
    days: Optional[int] = None

    hours: Optional[int] = None

    minutes: Optional[int] = None

    seconds: Optional[int] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenSleepStep(BaseModel):
    sleep: MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenSleepStepSleep

    kind: Optional[Literal["sleep"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenErrorWorkflowStep(BaseModel):
    error: str

    kind: Optional[Literal["error"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenWaitForInputStepWaitForInput(BaseModel):
    info: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]]


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenWaitForInputStep(BaseModel):
    wait_for_input: MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenWaitForInputStepWaitForInput

    kind: Optional[Literal["wait_for_input"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThen: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenEvaluateStep,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenToolCallStep,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenPromptStepOutput,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenGetStep,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenSetStep,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenLogStep,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenYieldStep,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenReturnStep,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenSleepStep,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenErrorWorkflowStep,
    MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThenWaitForInputStep,
]


class MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitch(BaseModel):
    case: Literal["_"]

    then: MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitchThen


class MainIfElseWorkflowStepOutputThenSwitchStepOutput(BaseModel):
    switch: List[MainIfElseWorkflowStepOutputThenSwitchStepOutputSwitch]

    kind: Optional[Literal["switch"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoWaitForInputStepWaitForInput(BaseModel):
    info: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]]


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoWaitForInputStep(BaseModel):
    wait_for_input: MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoWaitForInputStepWaitForInput

    kind: Optional[Literal["wait_for_input"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1Content(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(
    BaseModel
):
    function: MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str],
        List[
            MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1
        ],
        str,
        None,
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[
        List[MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCall]
    ] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoiceFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoiceFunction
    ] = None


MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoice,
    None,
]


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(
    BaseModel
):
    id: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(
    BaseModel
):
    name: Optional[str] = None


MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(
    BaseModel
):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(
    BaseModel
):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(
    BaseModel
):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(
    BaseModel
):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutput(
    BaseModel
):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem
    ] = None
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutput(BaseModel):
    prompt: Union[
        List[MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0], str
    ]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolChoice] = None

    tools: Union[
        Literal["all"],
        List[MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1],
        None,
    ] = None

    unwrap: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDo: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoWaitForInputStep,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoEvaluateStep,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoToolCallStep,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoPromptStepOutput,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoGetStep,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoSetStep,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoLogStep,
    MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDoYieldStep,
]


class MainIfElseWorkflowStepOutputThenForeachStepOutputForeach(BaseModel):
    do: MainIfElseWorkflowStepOutputThenForeachStepOutputForeachDo

    in_: str = FieldInfo(alias="in")


class MainIfElseWorkflowStepOutputThenForeachStepOutput(BaseModel):
    foreach: MainIfElseWorkflowStepOutputThenForeachStepOutputForeach

    kind: Optional[Literal["foreach"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1Content(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(
    BaseModel
):
    function: MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str],
        List[
            MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1
        ],
        str,
        None,
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[
        List[MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCall]
    ] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoiceFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoiceFunction
    ] = None


MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoice,
    None,
]


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(
    BaseModel
):
    id: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(
    BaseModel
):
    name: Optional[str] = None


MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(
    BaseModel
):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(
    BaseModel
):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(
    BaseModel
):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(
    BaseModel
):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutput(
    BaseModel
):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem
    ] = None
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutput(BaseModel):
    prompt: Union[
        List[MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputPromptUnionMember0], str
    ]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolChoice] = None

    tools: Union[
        Literal["all"],
        List[MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutputToolsUnionMember1],
        None,
    ] = None

    unwrap: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenParallelStepOutputParallelYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainIfElseWorkflowStepOutputThenParallelStepOutputParallel: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelEvaluateStep,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelToolCallStep,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelPromptStepOutput,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelGetStep,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelSetStep,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelLogStep,
    MainIfElseWorkflowStepOutputThenParallelStepOutputParallelYieldStep,
]


class MainIfElseWorkflowStepOutputThenParallelStepOutput(BaseModel):
    parallel: List[MainIfElseWorkflowStepOutputThenParallelStepOutputParallel]

    kind: Optional[Literal["parallel"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1Content(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(
    BaseModel
):
    function: MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str],
        List[MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1],
        str,
        None,
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[
        List[MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0ToolCall]
    ] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolChoiceNamedToolChoiceFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolChoiceNamedToolChoiceFunction
    ] = None


MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolChoiceNamedToolChoice,
    None,
]


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(BaseModel):
    id: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(BaseModel):
    name: Optional[str] = None


MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(
    BaseModel
):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(
    BaseModel
):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(
    BaseModel
):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(
    BaseModel
):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutput(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem
    ] = None
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutput(BaseModel):
    prompt: Union[List[MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputPromptUnionMember0], str]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolChoice] = None

    tools: Union[
        Literal["all"], List[MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutputToolsUnionMember1], None
    ] = None

    unwrap: Optional[bool] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputThenThenOutputMapYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainIfElseWorkflowStepOutputThenThenOutputMap: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenThenOutputMapEvaluateStep,
    MainIfElseWorkflowStepOutputThenThenOutputMapToolCallStep,
    MainIfElseWorkflowStepOutputThenThenOutputMapPromptStepOutput,
    MainIfElseWorkflowStepOutputThenThenOutputMapGetStep,
    MainIfElseWorkflowStepOutputThenThenOutputMapSetStep,
    MainIfElseWorkflowStepOutputThenThenOutputMapLogStep,
    MainIfElseWorkflowStepOutputThenThenOutputMapYieldStep,
]


class MainIfElseWorkflowStepOutputThenThenOutput(BaseModel):
    map: MainIfElseWorkflowStepOutputThenThenOutputMap

    over: str

    initial: Optional[object] = None

    kind: Optional[Literal["map_reduce"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    parallelism: Optional[int] = None

    reduce: Optional[str] = None


MainIfElseWorkflowStepOutputThen: TypeAlias = Union[
    MainIfElseWorkflowStepOutputThenWaitForInputStep,
    MainIfElseWorkflowStepOutputThenEvaluateStep,
    MainIfElseWorkflowStepOutputThenToolCallStep,
    MainIfElseWorkflowStepOutputThenPromptStepOutput,
    MainIfElseWorkflowStepOutputThenGetStep,
    MainIfElseWorkflowStepOutputThenSetStep,
    MainIfElseWorkflowStepOutputThenLogStep,
    MainIfElseWorkflowStepOutputThenYieldStep,
    MainIfElseWorkflowStepOutputThenReturnStep,
    MainIfElseWorkflowStepOutputThenSleepStep,
    MainIfElseWorkflowStepOutputThenErrorWorkflowStep,
    MainIfElseWorkflowStepOutputThenSwitchStepOutput,
    MainIfElseWorkflowStepOutputThenForeachStepOutput,
    MainIfElseWorkflowStepOutputThenParallelStepOutput,
    MainIfElseWorkflowStepOutputThenThenOutput,
    object,
]


class MainIfElseWorkflowStepOutputElseWaitForInputStepWaitForInput(BaseModel):
    info: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]]


class MainIfElseWorkflowStepOutputElseWaitForInputStep(BaseModel):
    wait_for_input: MainIfElseWorkflowStepOutputElseWaitForInputStepWaitForInput

    kind: Optional[Literal["wait_for_input"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1Content(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(BaseModel):
    function: MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str],
        List[MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ContentUnionMember1],
        str,
        None,
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0ToolCall]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolChoiceNamedToolChoiceFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[MainIfElseWorkflowStepOutputElsePromptStepOutputToolChoiceNamedToolChoiceFunction] = None


MainIfElseWorkflowStepOutputElsePromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainIfElseWorkflowStepOutputElsePromptStepOutputToolChoiceNamedToolChoice, None
]


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(BaseModel):
    id: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(BaseModel):
    name: Optional[str] = None


MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(BaseModel):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(
    BaseModel
):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(BaseModel):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(BaseModel):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutput(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem] = (
        None
    )
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainIfElseWorkflowStepOutputElsePromptStepOutput(BaseModel):
    prompt: Union[List[MainIfElseWorkflowStepOutputElsePromptStepOutputPromptUnionMember0], str]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainIfElseWorkflowStepOutputElsePromptStepOutputToolChoice] = None

    tools: Union[Literal["all"], List[MainIfElseWorkflowStepOutputElsePromptStepOutputToolsUnionMember1], None] = None

    unwrap: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseReturnStep(BaseModel):
    return_: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]] = FieldInfo(alias="return")

    kind: Optional[Literal["return"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSleepStepSleep(BaseModel):
    days: Optional[int] = None

    hours: Optional[int] = None

    minutes: Optional[int] = None

    seconds: Optional[int] = None


class MainIfElseWorkflowStepOutputElseSleepStep(BaseModel):
    sleep: MainIfElseWorkflowStepOutputElseSleepStepSleep

    kind: Optional[Literal["sleep"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseErrorWorkflowStep(BaseModel):
    error: str

    kind: Optional[Literal["error"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(
    BaseModel
):
    function: MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str],
        List[
            MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1
        ],
        str,
        None,
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[
        List[MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCall]
    ] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoiceFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoiceFunction
    ] = None


MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoice,
    None,
]


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(
    BaseModel
):
    id: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(
    BaseModel
):
    name: Optional[str] = None


MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(
    BaseModel
):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(
    BaseModel
):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(
    BaseModel
):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(
    BaseModel
):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput(
    BaseModel
):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem
    ] = None
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutput(BaseModel):
    prompt: Union[
        List[MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0], str
    ]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolChoice] = None

    tools: Union[
        Literal["all"],
        List[MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1],
        None,
    ] = None

    unwrap: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenReturnStep(BaseModel):
    return_: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]] = FieldInfo(alias="return")

    kind: Optional[Literal["return"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenSleepStepSleep(BaseModel):
    days: Optional[int] = None

    hours: Optional[int] = None

    minutes: Optional[int] = None

    seconds: Optional[int] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenSleepStep(BaseModel):
    sleep: MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenSleepStepSleep

    kind: Optional[Literal["sleep"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenErrorWorkflowStep(BaseModel):
    error: str

    kind: Optional[Literal["error"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenWaitForInputStepWaitForInput(BaseModel):
    info: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]]


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenWaitForInputStep(BaseModel):
    wait_for_input: MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenWaitForInputStepWaitForInput

    kind: Optional[Literal["wait_for_input"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThen: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenEvaluateStep,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenToolCallStep,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenPromptStepOutput,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenGetStep,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenSetStep,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenLogStep,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenYieldStep,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenReturnStep,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenSleepStep,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenErrorWorkflowStep,
    MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThenWaitForInputStep,
]


class MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitch(BaseModel):
    case: Literal["_"]

    then: MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitchThen


class MainIfElseWorkflowStepOutputElseSwitchStepOutput(BaseModel):
    switch: List[MainIfElseWorkflowStepOutputElseSwitchStepOutputSwitch]

    kind: Optional[Literal["switch"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoWaitForInputStepWaitForInput(BaseModel):
    info: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]]


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoWaitForInputStep(BaseModel):
    wait_for_input: MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoWaitForInputStepWaitForInput

    kind: Optional[Literal["wait_for_input"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1Content(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(
    BaseModel
):
    function: MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str],
        List[
            MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1
        ],
        str,
        None,
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[
        List[MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCall]
    ] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoiceFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoiceFunction
    ] = None


MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoice,
    None,
]


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(
    BaseModel
):
    id: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(
    BaseModel
):
    name: Optional[str] = None


MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(
    BaseModel
):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(
    BaseModel
):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(
    BaseModel
):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(
    BaseModel
):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutput(
    BaseModel
):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem
    ] = None
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutput(BaseModel):
    prompt: Union[
        List[MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0], str
    ]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolChoice] = None

    tools: Union[
        Literal["all"],
        List[MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1],
        None,
    ] = None

    unwrap: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDo: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoWaitForInputStep,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoEvaluateStep,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoToolCallStep,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoPromptStepOutput,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoGetStep,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoSetStep,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoLogStep,
    MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDoYieldStep,
]


class MainIfElseWorkflowStepOutputElseForeachStepOutputForeach(BaseModel):
    do: MainIfElseWorkflowStepOutputElseForeachStepOutputForeachDo

    in_: str = FieldInfo(alias="in")


class MainIfElseWorkflowStepOutputElseForeachStepOutput(BaseModel):
    foreach: MainIfElseWorkflowStepOutputElseForeachStepOutputForeach

    kind: Optional[Literal["foreach"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1Content(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(
    BaseModel
):
    function: MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str],
        List[
            MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1
        ],
        str,
        None,
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[
        List[MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCall]
    ] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoiceFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoiceFunction
    ] = None


MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoice,
    None,
]


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(
    BaseModel
):
    id: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(
    BaseModel
):
    name: Optional[str] = None


MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(
    BaseModel
):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(
    BaseModel
):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(
    BaseModel
):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(
    BaseModel
):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutput(
    BaseModel
):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem
    ] = None
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutput(BaseModel):
    prompt: Union[
        List[MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputPromptUnionMember0], str
    ]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolChoice] = None

    tools: Union[
        Literal["all"],
        List[MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutputToolsUnionMember1],
        None,
    ] = None

    unwrap: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseParallelStepOutputParallelYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainIfElseWorkflowStepOutputElseParallelStepOutputParallel: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelEvaluateStep,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelToolCallStep,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelPromptStepOutput,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelGetStep,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelSetStep,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelLogStep,
    MainIfElseWorkflowStepOutputElseParallelStepOutputParallelYieldStep,
]


class MainIfElseWorkflowStepOutputElseParallelStepOutput(BaseModel):
    parallel: List[MainIfElseWorkflowStepOutputElseParallelStepOutputParallel]

    kind: Optional[Literal["parallel"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1Content(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(
    BaseModel
):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(
    BaseModel
):
    function: MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(
    BaseModel
):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str],
        List[MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1],
        str,
        None,
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[
        List[MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0ToolCall]
    ] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolChoiceNamedToolChoiceFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolChoiceNamedToolChoiceFunction
    ] = None


MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"],
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolChoiceNamedToolChoice,
    None,
]


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(BaseModel):
    id: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(BaseModel):
    name: Optional[str] = None


MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(
    BaseModel
):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(
    BaseModel
):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(
    BaseModel
):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(
    BaseModel
):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutput(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem
    ] = None
    """System definition"""

    text_editor_20241022: Optional[
        MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1ToolRef,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutput(BaseModel):
    prompt: Union[List[MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputPromptUnionMember0], str]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolChoice] = None

    tools: Union[
        Literal["all"], List[MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutputToolsUnionMember1], None
    ] = None

    unwrap: Optional[bool] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainIfElseWorkflowStepOutputElseElseOutputMapYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainIfElseWorkflowStepOutputElseElseOutputMap: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseElseOutputMapEvaluateStep,
    MainIfElseWorkflowStepOutputElseElseOutputMapToolCallStep,
    MainIfElseWorkflowStepOutputElseElseOutputMapPromptStepOutput,
    MainIfElseWorkflowStepOutputElseElseOutputMapGetStep,
    MainIfElseWorkflowStepOutputElseElseOutputMapSetStep,
    MainIfElseWorkflowStepOutputElseElseOutputMapLogStep,
    MainIfElseWorkflowStepOutputElseElseOutputMapYieldStep,
]


class MainIfElseWorkflowStepOutputElseElseOutput(BaseModel):
    map: MainIfElseWorkflowStepOutputElseElseOutputMap

    over: str

    initial: Optional[object] = None

    kind: Optional[Literal["map_reduce"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    parallelism: Optional[int] = None

    reduce: Optional[str] = None


MainIfElseWorkflowStepOutputElse: TypeAlias = Union[
    MainIfElseWorkflowStepOutputElseWaitForInputStep,
    MainIfElseWorkflowStepOutputElseEvaluateStep,
    MainIfElseWorkflowStepOutputElseToolCallStep,
    MainIfElseWorkflowStepOutputElsePromptStepOutput,
    MainIfElseWorkflowStepOutputElseGetStep,
    MainIfElseWorkflowStepOutputElseSetStep,
    MainIfElseWorkflowStepOutputElseLogStep,
    MainIfElseWorkflowStepOutputElseYieldStep,
    MainIfElseWorkflowStepOutputElseReturnStep,
    MainIfElseWorkflowStepOutputElseSleepStep,
    MainIfElseWorkflowStepOutputElseErrorWorkflowStep,
    MainIfElseWorkflowStepOutputElseSwitchStepOutput,
    MainIfElseWorkflowStepOutputElseForeachStepOutput,
    MainIfElseWorkflowStepOutputElseParallelStepOutput,
    MainIfElseWorkflowStepOutputElseElseOutput,
    object,
    None,
]


class MainIfElseWorkflowStepOutput(BaseModel):
    if_: str = FieldInfo(alias="if")

    then: MainIfElseWorkflowStepOutputThen
    """The steps to run if the condition is true"""

    else_: Optional[MainIfElseWorkflowStepOutputElse] = FieldInfo(alias="else", default=None)
    """The steps to run if the condition is false"""

    kind: Optional[Literal["if_else"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSwitchStepOutputSwitchThenEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSwitchStepOutputSwitchThenToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(BaseModel):
    function: MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str], List[MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ContentUnionMember1], str, None
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0ToolCall]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoiceFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[MainSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoiceFunction] = None


MainSwitchStepOutputSwitchThenPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainSwitchStepOutputSwitchThenPromptStepOutputToolChoiceNamedToolChoice, None
]


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(BaseModel):
    id: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(BaseModel):
    name: Optional[str] = None


MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(BaseModel):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(BaseModel):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(BaseModel):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(BaseModel):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem] = (
        None
    )
    """System definition"""

    text_editor_20241022: Optional[
        MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1ToolRef,
    MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainSwitchStepOutputSwitchThenPromptStepOutput(BaseModel):
    prompt: Union[List[MainSwitchStepOutputSwitchThenPromptStepOutputPromptUnionMember0], str]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainSwitchStepOutputSwitchThenPromptStepOutputToolChoice] = None

    tools: Union[Literal["all"], List[MainSwitchStepOutputSwitchThenPromptStepOutputToolsUnionMember1], None] = None

    unwrap: Optional[bool] = None


class MainSwitchStepOutputSwitchThenGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSwitchStepOutputSwitchThenSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSwitchStepOutputSwitchThenLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSwitchStepOutputSwitchThenYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSwitchStepOutputSwitchThenReturnStep(BaseModel):
    return_: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]] = FieldInfo(alias="return")

    kind: Optional[Literal["return"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSwitchStepOutputSwitchThenSleepStepSleep(BaseModel):
    days: Optional[int] = None

    hours: Optional[int] = None

    minutes: Optional[int] = None

    seconds: Optional[int] = None


class MainSwitchStepOutputSwitchThenSleepStep(BaseModel):
    sleep: MainSwitchStepOutputSwitchThenSleepStepSleep

    kind: Optional[Literal["sleep"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSwitchStepOutputSwitchThenErrorWorkflowStep(BaseModel):
    error: str

    kind: Optional[Literal["error"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainSwitchStepOutputSwitchThenWaitForInputStepWaitForInput(BaseModel):
    info: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]]


class MainSwitchStepOutputSwitchThenWaitForInputStep(BaseModel):
    wait_for_input: MainSwitchStepOutputSwitchThenWaitForInputStepWaitForInput

    kind: Optional[Literal["wait_for_input"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainSwitchStepOutputSwitchThen: TypeAlias = Union[
    MainSwitchStepOutputSwitchThenEvaluateStep,
    MainSwitchStepOutputSwitchThenToolCallStep,
    MainSwitchStepOutputSwitchThenPromptStepOutput,
    MainSwitchStepOutputSwitchThenGetStep,
    MainSwitchStepOutputSwitchThenSetStep,
    MainSwitchStepOutputSwitchThenLogStep,
    MainSwitchStepOutputSwitchThenYieldStep,
    MainSwitchStepOutputSwitchThenReturnStep,
    MainSwitchStepOutputSwitchThenSleepStep,
    MainSwitchStepOutputSwitchThenErrorWorkflowStep,
    MainSwitchStepOutputSwitchThenWaitForInputStep,
]


class MainSwitchStepOutputSwitch(BaseModel):
    case: Literal["_"]

    then: MainSwitchStepOutputSwitchThen


class MainSwitchStepOutput(BaseModel):
    switch: List[MainSwitchStepOutputSwitch]

    kind: Optional[Literal["switch"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainForeachStepOutputForeachDoWaitForInputStepWaitForInput(BaseModel):
    info: Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]]


class MainForeachStepOutputForeachDoWaitForInputStep(BaseModel):
    wait_for_input: MainForeachStepOutputForeachDoWaitForInputStepWaitForInput

    kind: Optional[Literal["wait_for_input"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainForeachStepOutputForeachDoEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainForeachStepOutputForeachDoToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1Content(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(BaseModel):
    function: MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str], List[MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ContentUnionMember1], str, None
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0ToolCall]] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoiceFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[MainForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoiceFunction] = None


MainForeachStepOutputForeachDoPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainForeachStepOutputForeachDoPromptStepOutputToolChoiceNamedToolChoice, None
]


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(BaseModel):
    id: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(BaseModel):
    name: Optional[str] = None


MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(BaseModel):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(BaseModel):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(BaseModel):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(BaseModel):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutput(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem] = (
        None
    )
    """System definition"""

    text_editor_20241022: Optional[
        MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1ToolRef,
    MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainForeachStepOutputForeachDoPromptStepOutput(BaseModel):
    prompt: Union[List[MainForeachStepOutputForeachDoPromptStepOutputPromptUnionMember0], str]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainForeachStepOutputForeachDoPromptStepOutputToolChoice] = None

    tools: Union[Literal["all"], List[MainForeachStepOutputForeachDoPromptStepOutputToolsUnionMember1], None] = None

    unwrap: Optional[bool] = None


class MainForeachStepOutputForeachDoGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainForeachStepOutputForeachDoSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainForeachStepOutputForeachDoLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainForeachStepOutputForeachDoYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainForeachStepOutputForeachDo: TypeAlias = Union[
    MainForeachStepOutputForeachDoWaitForInputStep,
    MainForeachStepOutputForeachDoEvaluateStep,
    MainForeachStepOutputForeachDoToolCallStep,
    MainForeachStepOutputForeachDoPromptStepOutput,
    MainForeachStepOutputForeachDoGetStep,
    MainForeachStepOutputForeachDoSetStep,
    MainForeachStepOutputForeachDoLogStep,
    MainForeachStepOutputForeachDoYieldStep,
]


class MainForeachStepOutputForeach(BaseModel):
    do: MainForeachStepOutputForeachDo

    in_: str = FieldInfo(alias="in")


class MainForeachStepOutput(BaseModel):
    foreach: MainForeachStepOutputForeach

    kind: Optional[Literal["foreach"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainParallelStepOutputParallelEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainParallelStepOutputParallelToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1Content(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(
    BaseModel
):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(BaseModel):
    function: MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str], List[MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ContentUnionMember1], str, None
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0ToolCall]] = None


class MainParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoiceFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[MainParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoiceFunction] = None


MainParallelStepOutputParallelPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainParallelStepOutputParallelPromptStepOutputToolChoiceNamedToolChoice, None
]


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(BaseModel):
    id: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(BaseModel):
    name: Optional[str] = None


MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(BaseModel):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(BaseModel):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(BaseModel):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(BaseModel):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(
    BaseModel
):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutput(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall
    ] = None
    """API call definition"""

    bash_20241022: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022
    ] = None

    computer_20241022: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction
    ] = None
    """Function definition"""

    integration: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration
    ] = None
    """Brave integration definition"""

    system: Optional[MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem] = (
        None
    )
    """System definition"""

    text_editor_20241022: Optional[
        MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1ToolRef,
    MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainParallelStepOutputParallelPromptStepOutput(BaseModel):
    prompt: Union[List[MainParallelStepOutputParallelPromptStepOutputPromptUnionMember0], str]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainParallelStepOutputParallelPromptStepOutputToolChoice] = None

    tools: Union[Literal["all"], List[MainParallelStepOutputParallelPromptStepOutputToolsUnionMember1], None] = None

    unwrap: Optional[bool] = None


class MainParallelStepOutputParallelGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainParallelStepOutputParallelSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainParallelStepOutputParallelLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainParallelStepOutputParallelYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainParallelStepOutputParallel: TypeAlias = Union[
    MainParallelStepOutputParallelEvaluateStep,
    MainParallelStepOutputParallelToolCallStep,
    MainParallelStepOutputParallelPromptStepOutput,
    MainParallelStepOutputParallelGetStep,
    MainParallelStepOutputParallelSetStep,
    MainParallelStepOutputParallelLogStep,
    MainParallelStepOutputParallelYieldStep,
]


class MainParallelStepOutput(BaseModel):
    parallel: List[MainParallelStepOutputParallel]

    kind: Optional[Literal["parallel"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainMainOutputMapEvaluateStep(BaseModel):
    evaluate: Dict[str, Union[str, object]]

    kind: Optional[Literal["evaluate"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainMainOutputMapToolCallStep(BaseModel):
    tool: str

    arguments: Union[Literal["_"], object, None] = None

    kind: Optional[Literal["tool_call"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1Content(BaseModel):
    text: str

    type: Optional[Literal["text"]] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL(
    BaseModel
):
    url: str

    detail: Optional[Literal["low", "high", "auto"]] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel(
    BaseModel
):
    image_url: (
        MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModelImageURL
    )
    """The image URL"""

    type: Optional[Literal["image_url"]] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0(
    BaseModel
):
    text: str

    type: Optional[Literal["text"]] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source(
    BaseModel
):
    data: str

    media_type: str

    type: Optional[Literal["base64"]] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1(
    BaseModel
):
    source: MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1Source

    type: Optional[Literal["image"]] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output(
    BaseModel
):
    content: Union[
        List[
            MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember0
        ],
        List[
            MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1OutputContentUnionMember1
        ],
    ]

    tool_use_id: str

    type: Optional[Literal["tool_result"]] = None


MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1: TypeAlias = Union[
    MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1Content,
    MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel,
    MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1AgentsAPIAutogenTasksContentModel1Output,
]


class MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall(BaseModel):
    function: MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallFunction

    id: Optional[str] = None

    api_call: Optional[object] = None

    bash_20241022: Optional[
        MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallBash20241022
    ] = None

    computer_20241022: Optional[
        MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallComputer20241022
    ] = None

    integration: Optional[object] = None

    system: Optional[object] = None

    text_editor_20241022: Optional[
        MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCallTextEditor20241022
    ] = None

    type: Optional[Literal["function"]] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022(BaseModel):
    action: Literal[
        "key",
        "type",
        "cursor_position",
        "mouse_move",
        "left_click",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
    ]

    coordinate: Optional[List[int]] = None

    text: Optional[str] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022(BaseModel):
    command: Literal["str_replace", "insert", "view", "undo_edit"]

    path: str

    file_text: Optional[str] = None

    insert_line: Optional[int] = None

    new_str: Optional[str] = None

    old_str: Optional[str] = None

    view_range: Optional[List[int]] = None


class MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022(BaseModel):
    command: Optional[str] = None

    restart: Optional[bool] = None


MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCall: TypeAlias = Union[
    MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenFunctionCall,
    MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenComputer20241022,
    MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenTextEditor20241022,
    MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCallChosenBash20241022,
]


class MainMainOutputMapPromptStepOutputPromptUnionMember0(BaseModel):
    content: Union[
        List[str], List[MainMainOutputMapPromptStepOutputPromptUnionMember0ContentUnionMember1], str, None
    ] = None

    role: Literal["user", "assistant", "system", "tool"]

    continue_: Optional[bool] = FieldInfo(alias="continue", default=None)

    name: Optional[str] = None

    tool_call_id: Optional[str] = None

    tool_calls: Optional[List[MainMainOutputMapPromptStepOutputPromptUnionMember0ToolCall]] = None


class MainMainOutputMapPromptStepOutputToolChoiceNamedToolChoiceFunction(BaseModel):
    name: str

    arguments: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolChoiceNamedToolChoice(BaseModel):
    function: Optional[MainMainOutputMapPromptStepOutputToolChoiceNamedToolChoiceFunction] = None


MainMainOutputMapPromptStepOutputToolChoice: TypeAlias = Union[
    Literal["auto", "none"], MainMainOutputMapPromptStepOutputToolChoiceNamedToolChoice, None
]


class MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID(BaseModel):
    id: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName(BaseModel):
    name: Optional[str] = None


MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRefRef: TypeAlias = Union[
    MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByID,
    MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRefRefToolRefByName,
]


class MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRef(BaseModel):
    ref: MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRefRef
    """Reference to a tool by id"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall(BaseModel):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022(BaseModel):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction(BaseModel):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef(
    BaseModel
):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments(
    BaseModel
):
    query: str


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup(
    BaseModel
):
    api_key: str


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefArguments
    ] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDefSetup
    ] = None
    """Integration definition for Brave Search"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments(
    BaseModel
):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup(
    BaseModel
):
    host: str

    password: str

    port: int

    user: str


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefArguments
    ] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDefSetup
    ] = None
    """Setup parameters for Email integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments(
    BaseModel
):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup(
    BaseModel
):
    spider_api_key: str


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputArguments
    ] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutputSetup
    ] = None
    """Setup parameters for Spider integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments(
    BaseModel
):
    query: str

    load_max_docs: Optional[int] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDefArguments
    ] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments(
    BaseModel
):
    location: str


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup(
    BaseModel
):
    openweathermap_api_key: str


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefArguments
    ] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDefSetup
    ] = None
    """Integration definition for Weather"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments(
    BaseModel
):
    project_id: str = FieldInfo(alias="projectId")


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments(
    BaseModel
):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefArguments
    ] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments(
    BaseModel
):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefArguments
    ] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments(
    BaseModel
):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments(
    BaseModel
):
    id: str


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(
    BaseModel
):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefArguments
    ] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(
    BaseModel
):
    id: str


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(
    BaseModel
):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments
    ] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup
    ] = None
    """The setup parameters for the browserbase integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup(
    BaseModel
):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments(
    BaseModel
):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef(
    BaseModel
):
    setup: MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDefArguments
    ] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments(
    BaseModel
):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup(
    BaseModel
):
    llamaparse_api_key: str

    params: Optional[object] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefArguments
    ] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDefSetup
    ] = None
    """Setup parameters for LlamaParse integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments(
    BaseModel
):
    cmd: str

    file: Union[str, List[str], None] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDefArguments
    ] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments(
    BaseModel
):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments(
    BaseModel
):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup(
    BaseModel
):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefArguments
    ] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDefSetup
    ] = None
    """Setup parameters for Cloudinary integration"""


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments(
    BaseModel
):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef(
    BaseModel
):
    arguments: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDefArguments
    ] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration: TypeAlias = Union[
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationDummyIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBraveIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationEmailIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationSpiderIntegrationDefOutput,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWikipediaIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationWeatherIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseContextIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseExtensionIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseListSessionsIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCreateSessionIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseCompleteSessionIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationRemoteBrowserIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationLlamaParseIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationFfmpegIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryUploadIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationCloudinaryEditIntegrationDef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegrationArxivIntegrationDef,
    None,
]


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem(BaseModel):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutput(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputAPICall] = None
    """API call definition"""

    bash_20241022: Optional[MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputBash20241022] = (
        None
    )

    computer_20241022: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputComputer20241022
    ] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputFunction] = None
    """Function definition"""

    integration: Optional[MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputIntegration] = None
    """Brave integration definition"""

    system: Optional[MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputSystem] = None
    """System definition"""

    text_editor_20241022: Optional[
        MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutputTextEditor20241022
    ] = None


MainMainOutputMapPromptStepOutputToolsUnionMember1: TypeAlias = Union[
    MainMainOutputMapPromptStepOutputToolsUnionMember1ToolRef,
    MainMainOutputMapPromptStepOutputToolsUnionMember1CreateToolRequestOutput,
]


class MainMainOutputMapPromptStepOutput(BaseModel):
    prompt: Union[List[MainMainOutputMapPromptStepOutputPromptUnionMember0], str]

    auto_run_tools: Optional[bool] = None

    disable_cache: Optional[bool] = None

    kind: Optional[Literal["prompt"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    settings: Optional[object] = None

    tool_choice: Optional[MainMainOutputMapPromptStepOutputToolChoice] = None

    tools: Union[Literal["all"], List[MainMainOutputMapPromptStepOutputToolsUnionMember1], None] = None

    unwrap: Optional[bool] = None


class MainMainOutputMapGetStep(BaseModel):
    get: str

    kind: Optional[Literal["get"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainMainOutputMapSetStep(BaseModel):
    set: Dict[str, Union[str, object]]

    kind: Optional[Literal["set"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainMainOutputMapLogStep(BaseModel):
    log: str

    kind: Optional[Literal["log"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


class MainMainOutputMapYieldStep(BaseModel):
    workflow: str

    arguments: Union[Dict[str, Union[List[str], Dict[str, str], List[Dict[str, str]], str]], Literal["_"], None] = None

    kind: Optional[Literal["yield"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None


MainMainOutputMap: TypeAlias = Union[
    MainMainOutputMapEvaluateStep,
    MainMainOutputMapToolCallStep,
    MainMainOutputMapPromptStepOutput,
    MainMainOutputMapGetStep,
    MainMainOutputMapSetStep,
    MainMainOutputMapLogStep,
    MainMainOutputMapYieldStep,
]


class MainMainOutput(BaseModel):
    map: MainMainOutputMap

    over: str

    initial: Optional[object] = None

    kind: Optional[Literal["map_reduce"]] = FieldInfo(alias="kind_", default=None)

    label: Optional[str] = None

    parallelism: Optional[int] = None

    reduce: Optional[str] = None


Main: TypeAlias = Union[
    MainEvaluateStep,
    MainToolCallStep,
    MainPromptStepOutput,
    MainGetStep,
    MainSetStep,
    MainLogStep,
    MainYieldStep,
    MainReturnStep,
    MainSleepStep,
    MainErrorWorkflowStep,
    MainWaitForInputStep,
    MainIfElseWorkflowStepOutput,
    MainSwitchStepOutput,
    MainForeachStepOutput,
    MainParallelStepOutput,
    MainMainOutput,
]


class ToolAPICall(BaseModel):
    method: Literal["GET", "POST", "PUT", "DELETE", "PATCH", "HEAD", "OPTIONS", "CONNECT", "TRACE"]

    url: str

    content: Optional[str] = None

    cookies: Optional[Dict[str, str]] = None

    data: Optional[object] = None

    files: Optional[object] = None

    follow_redirects: Optional[bool] = None

    headers: Optional[Dict[str, str]] = None

    json_: Optional[object] = FieldInfo(alias="json", default=None)

    params: Union[str, object, None] = None

    schema_: Optional[object] = FieldInfo(alias="schema", default=None)

    timeout: Optional[int] = None


class ToolBash20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["bash_20241022"]] = None


class ToolComputer20241022(BaseModel):
    display_height_px: Optional[int] = None

    display_number: Optional[int] = None

    display_width_px: Optional[int] = None

    name: Optional[str] = None

    type: Optional[Literal["computer_20241022"]] = None


class ToolFunction(BaseModel):
    description: Optional[object] = None

    name: Optional[object] = None

    parameters: Optional[object] = None


class ToolIntegrationDummyIntegrationDef(BaseModel):
    arguments: Optional[object] = None

    method: Optional[str] = None

    provider: Optional[Literal["dummy"]] = None

    setup: Optional[object] = None


class ToolIntegrationBraveIntegrationDefArguments(BaseModel):
    query: str


class ToolIntegrationBraveIntegrationDefSetup(BaseModel):
    api_key: str


class ToolIntegrationBraveIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationBraveIntegrationDefArguments] = None
    """Arguments for Brave Search"""

    method: Optional[str] = None

    provider: Optional[Literal["brave"]] = None

    setup: Optional[ToolIntegrationBraveIntegrationDefSetup] = None
    """Integration definition for Brave Search"""


class ToolIntegrationEmailIntegrationDefArguments(BaseModel):
    body: str

    from_: str = FieldInfo(alias="from")

    subject: str

    to: str


class ToolIntegrationEmailIntegrationDefSetup(BaseModel):
    host: str

    password: str

    port: int

    user: str


class ToolIntegrationEmailIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationEmailIntegrationDefArguments] = None
    """Arguments for Email sending"""

    method: Optional[str] = None

    provider: Optional[Literal["email"]] = None

    setup: Optional[ToolIntegrationEmailIntegrationDefSetup] = None
    """Setup parameters for Email integration"""


class ToolIntegrationSpiderIntegrationDefOutputArguments(BaseModel):
    url: str

    content_type: Optional[Literal["application/json", "text/csv", "application/xml", "application/jsonl"]] = None

    params: Optional[object] = None


class ToolIntegrationSpiderIntegrationDefOutputSetup(BaseModel):
    spider_api_key: str


class ToolIntegrationSpiderIntegrationDefOutput(BaseModel):
    arguments: Optional[ToolIntegrationSpiderIntegrationDefOutputArguments] = None
    """Arguments for Spider integration"""

    method: Optional[Literal["crawl", "links", "screenshot", "search"]] = None

    provider: Optional[Literal["spider"]] = None

    setup: Optional[ToolIntegrationSpiderIntegrationDefOutputSetup] = None
    """Setup parameters for Spider integration"""


class ToolIntegrationWikipediaIntegrationDefArguments(BaseModel):
    query: str

    load_max_docs: Optional[int] = None


class ToolIntegrationWikipediaIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationWikipediaIntegrationDefArguments] = None
    """Arguments for Wikipedia Search"""

    method: Optional[str] = None

    provider: Optional[Literal["wikipedia"]] = None

    setup: Optional[object] = None


class ToolIntegrationWeatherIntegrationDefArguments(BaseModel):
    location: str


class ToolIntegrationWeatherIntegrationDefSetup(BaseModel):
    openweathermap_api_key: str


class ToolIntegrationWeatherIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationWeatherIntegrationDefArguments] = None
    """Arguments for Weather"""

    method: Optional[str] = None

    provider: Optional[Literal["weather"]] = None

    setup: Optional[ToolIntegrationWeatherIntegrationDefSetup] = None
    """Integration definition for Weather"""


class ToolIntegrationBrowserbaseContextIntegrationDefArguments(BaseModel):
    project_id: str = FieldInfo(alias="projectId")


class ToolIntegrationBrowserbaseContextIntegrationDefSetup(BaseModel):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class ToolIntegrationBrowserbaseContextIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationBrowserbaseContextIntegrationDefArguments] = None

    method: Optional[Literal["create_context"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[ToolIntegrationBrowserbaseContextIntegrationDefSetup] = None
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseExtensionIntegrationDefArguments(BaseModel):
    repository_name: str = FieldInfo(alias="repositoryName")

    ref: Optional[str] = None


class ToolIntegrationBrowserbaseExtensionIntegrationDefSetup(BaseModel):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class ToolIntegrationBrowserbaseExtensionIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationBrowserbaseExtensionIntegrationDefArguments] = None

    method: Optional[Literal["install_extension_from_github"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[ToolIntegrationBrowserbaseExtensionIntegrationDefSetup] = None
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments(BaseModel):
    status: Optional[Literal["RUNNING", "ERROR", "TIMED_OUT", "COMPLETED"]] = None


class ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup(BaseModel):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class ToolIntegrationBrowserbaseListSessionsIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationBrowserbaseListSessionsIntegrationDefArguments] = None

    method: Optional[Literal["list_sessions"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[ToolIntegrationBrowserbaseListSessionsIntegrationDefSetup] = None
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments(BaseModel):
    browser_settings: Optional[object] = FieldInfo(alias="browserSettings", default=None)

    extension_id: Optional[str] = FieldInfo(alias="extensionId", default=None)

    keep_alive: Optional[bool] = FieldInfo(alias="keepAlive", default=None)

    project_id: Optional[str] = FieldInfo(alias="projectId", default=None)

    proxies: Union[bool, List[object], None] = None

    timeout: Optional[int] = None


class ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup(BaseModel):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class ToolIntegrationBrowserbaseCreateSessionIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationBrowserbaseCreateSessionIntegrationDefArguments] = None

    method: Optional[Literal["create_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[ToolIntegrationBrowserbaseCreateSessionIntegrationDefSetup] = None
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments(BaseModel):
    id: str


class ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup(BaseModel):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class ToolIntegrationBrowserbaseGetSessionIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationBrowserbaseGetSessionIntegrationDefArguments] = None

    method: Optional[Literal["get_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[ToolIntegrationBrowserbaseGetSessionIntegrationDefSetup] = None
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments(BaseModel):
    id: str

    status: Optional[Literal["REQUEST_RELEASE"]] = None


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup(BaseModel):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class ToolIntegrationBrowserbaseCompleteSessionIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationBrowserbaseCompleteSessionIntegrationDefArguments] = None

    method: Optional[Literal["complete_session"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[ToolIntegrationBrowserbaseCompleteSessionIntegrationDefSetup] = None
    """The setup parameters for the browserbase integration"""


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments(BaseModel):
    id: str


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup(BaseModel):
    api_key: str

    project_id: str

    api_url: Optional[str] = None

    connect_url: Optional[str] = None


class ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefArguments] = None

    method: Optional[Literal["get_live_urls"]] = None

    provider: Optional[Literal["browserbase"]] = None

    setup: Optional[ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDefSetup] = None
    """The setup parameters for the browserbase integration"""


class ToolIntegrationRemoteBrowserIntegrationDefSetup(BaseModel):
    connect_url: Optional[str] = None

    height: Optional[int] = None

    width: Optional[int] = None


class ToolIntegrationRemoteBrowserIntegrationDefArguments(BaseModel):
    action: Literal[
        "key",
        "type",
        "mouse_move",
        "left_click",
        "left_click_drag",
        "right_click",
        "middle_click",
        "double_click",
        "screenshot",
        "cursor_position",
        "navigate",
        "refresh",
    ]

    connect_url: Optional[str] = None

    coordinate: Optional[List[object]] = None

    text: Optional[str] = None


class ToolIntegrationRemoteBrowserIntegrationDef(BaseModel):
    setup: ToolIntegrationRemoteBrowserIntegrationDefSetup
    """The setup parameters for the remote browser"""

    arguments: Optional[ToolIntegrationRemoteBrowserIntegrationDefArguments] = None
    """The arguments for the remote browser"""

    method: Optional[Literal["perform_action"]] = None

    provider: Optional[Literal["remote_browser"]] = None


class ToolIntegrationLlamaParseIntegrationDefArguments(BaseModel):
    file: Union[str, List[str]]

    base64: Optional[bool] = None

    filename: Optional[str] = None

    params: Optional[object] = None


class ToolIntegrationLlamaParseIntegrationDefSetup(BaseModel):
    llamaparse_api_key: str

    params: Optional[object] = None


class ToolIntegrationLlamaParseIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationLlamaParseIntegrationDefArguments] = None
    """Arguments for LlamaParse integration"""

    method: Optional[str] = None

    provider: Optional[Literal["llama_parse"]] = None

    setup: Optional[ToolIntegrationLlamaParseIntegrationDefSetup] = None
    """Setup parameters for LlamaParse integration"""


class ToolIntegrationFfmpegIntegrationDefArguments(BaseModel):
    cmd: str

    file: Union[str, List[str], None] = None


class ToolIntegrationFfmpegIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationFfmpegIntegrationDefArguments] = None
    """Arguments for Ffmpeg CMD"""

    method: Optional[str] = None

    provider: Optional[Literal["ffmpeg"]] = None

    setup: Optional[object] = None


class ToolIntegrationCloudinaryUploadIntegrationDefArguments(BaseModel):
    file: str

    public_id: Optional[str] = None

    return_base64: Optional[bool] = None

    upload_params: Optional[object] = None


class ToolIntegrationCloudinaryUploadIntegrationDefSetup(BaseModel):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class ToolIntegrationCloudinaryUploadIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationCloudinaryUploadIntegrationDefArguments] = None
    """Arguments for Cloudinary media upload"""

    method: Optional[Literal["media_upload"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[ToolIntegrationCloudinaryUploadIntegrationDefSetup] = None
    """Setup parameters for Cloudinary integration"""


class ToolIntegrationCloudinaryEditIntegrationDefArguments(BaseModel):
    public_id: str

    transformation: List[object]

    return_base64: Optional[bool] = None


class ToolIntegrationCloudinaryEditIntegrationDefSetup(BaseModel):
    cloudinary_api_key: str

    cloudinary_api_secret: str

    cloudinary_cloud_name: str

    params: Optional[object] = None


class ToolIntegrationCloudinaryEditIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationCloudinaryEditIntegrationDefArguments] = None
    """Arguments for Cloudinary media edit"""

    method: Optional[Literal["media_edit"]] = None

    provider: Optional[Literal["cloudinary"]] = None

    setup: Optional[ToolIntegrationCloudinaryEditIntegrationDefSetup] = None
    """Setup parameters for Cloudinary integration"""


class ToolIntegrationArxivIntegrationDefArguments(BaseModel):
    query: str

    download_pdf: Optional[bool] = None

    id_list: Optional[List[str]] = None

    max_results: Optional[int] = None

    sort_by: Optional[Literal["relevance", "lastUpdatedDate", "submittedDate"]] = None

    sort_order: Optional[Literal["ascending", "descending"]] = None


class ToolIntegrationArxivIntegrationDef(BaseModel):
    arguments: Optional[ToolIntegrationArxivIntegrationDefArguments] = None
    """Arguments for Arxiv Search"""

    method: Optional[str] = None

    provider: Optional[Literal["arxiv"]] = None

    setup: Optional[object] = None


ToolIntegration: TypeAlias = Union[
    ToolIntegrationDummyIntegrationDef,
    ToolIntegrationBraveIntegrationDef,
    ToolIntegrationEmailIntegrationDef,
    ToolIntegrationSpiderIntegrationDefOutput,
    ToolIntegrationWikipediaIntegrationDef,
    ToolIntegrationWeatherIntegrationDef,
    ToolIntegrationBrowserbaseContextIntegrationDef,
    ToolIntegrationBrowserbaseExtensionIntegrationDef,
    ToolIntegrationBrowserbaseListSessionsIntegrationDef,
    ToolIntegrationBrowserbaseCreateSessionIntegrationDef,
    ToolIntegrationBrowserbaseGetSessionIntegrationDef,
    ToolIntegrationBrowserbaseCompleteSessionIntegrationDef,
    ToolIntegrationBrowserbaseGetSessionLiveURLsIntegrationDef,
    ToolIntegrationRemoteBrowserIntegrationDef,
    ToolIntegrationLlamaParseIntegrationDef,
    ToolIntegrationFfmpegIntegrationDef,
    ToolIntegrationCloudinaryUploadIntegrationDef,
    ToolIntegrationCloudinaryEditIntegrationDef,
    ToolIntegrationArxivIntegrationDef,
    None,
]


class ToolSystem(BaseModel):
    operation: Literal[
        "create",
        "update",
        "patch",
        "create_or_update",
        "embed",
        "change_status",
        "search",
        "chat",
        "history",
        "delete",
        "get",
        "list",
    ]

    resource: Literal["agent", "user", "task", "execution", "doc", "session", "job"]

    arguments: Optional[object] = None

    resource_id: Optional[str] = None

    subresource: Optional[Literal["tool", "doc", "execution", "transition"]] = None


class ToolTextEditor20241022(BaseModel):
    name: Optional[str] = None

    type: Optional[Literal["text_editor_20241022"]] = None


class Tool(BaseModel):
    name: str

    type: Literal[
        "function", "integration", "system", "api_call", "computer_20241022", "text_editor_20241022", "bash_20241022"
    ]

    api_call: Optional[ToolAPICall] = None
    """API call definition"""

    bash_20241022: Optional[ToolBash20241022] = None

    computer_20241022: Optional[ToolComputer20241022] = None
    """Anthropic new tools"""

    description: Optional[str] = None

    function: Optional[ToolFunction] = None
    """Function definition"""

    inherited: Optional[bool] = None

    integration: Optional[ToolIntegration] = None
    """Brave integration definition"""

    system: Optional[ToolSystem] = None
    """System definition"""

    text_editor_20241022: Optional[ToolTextEditor20241022] = None


class Task(BaseModel):
    id: str

    created_at: datetime

    main: List[Main]

    name: str

    updated_at: datetime

    canonical_name: Optional[str] = None

    description: Optional[str] = None

    inherit_tools: Optional[bool] = None

    input_schema: Optional[object] = None

    metadata: Optional[object] = None

    tools: Optional[List[Tool]] = None

    if TYPE_CHECKING:
        # Stub to indicate that arbitrary properties are accepted.
        # To access properties that are not valid identifiers you can use `getattr`, e.g.
        # `getattr(obj, '$type')`
        def __getattr__(self, attr: str) -> object: ...
